==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/ro/lang.php <==
<?php
/**
 * romanian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Tiberiu Micu <tibimicu@gmx.net>
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Editează această pagină';
$lang['btn_source']            = 'Arată sursa paginii';
$lang['btn_show']              = 'Arată pagina';
$lang['btn_create']            = 'Crează această pagină';
$lang['btn_search']            = 'Caută';
$lang['btn_save']              = 'Salvează';
$lang['btn_preview']           = 'Previzualizează';
$lang['btn_top']               = 'La început';
$lang['btn_newer']             = '<< mai recent';
$lang['btn_older']             = 'mai vechi>>';
$lang['btn_revs']              = 'Versiuni vechi';
$lang['btn_recent']            = 'Modificări recente';
$lang['btn_upload']            = 'Upload';
$lang['btn_cancel']            = 'Renunţare';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Editează';
$lang['btn_login']             = 'Login';
$lang['btn_logout']            = 'Logout';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Actualizează';
$lang['btn_delete']            = 'Şterge';
$lang['btn_back']              = 'Înapoi';
$lang['btn_backlink']          = 'Legătură anterioară';
$lang['btn_backtomedia']       = 'Înapoi la Selecţia Mediafile';
$lang['btn_subscribe']         = 'Subscrie Modificarea Paginii';
$lang['btn_unsubscribe']       = 'Anulează Subscrierea Modificării Paginii';
$lang['btn_subscribens']       = 'Subscrie Modificarea Spaţiului de Nume';
$lang['btn_unsubscribens']     = 'Anulează Subscrierea Modificării Spaţiului de Nume';
$lang['btn_profile']           = 'Actualizează Profil';
$lang['btn_reset']             = 'Resetează';
$lang['btn_resendpwd']         = 'Trimite parola nouă';
$lang['btn_draft']             = 'Editează schiţă';
$lang['btn_recover']           = 'Recuperează schiţă';
$lang['btn_draftdel']          = 'Şterge schiţă';
$lang['loggedinas']            = 'Logat ca şi';
$lang['user']                  = 'Utilizator';
$lang['pass']                  = 'Parola';
$lang['newpass']               = 'Parola nouă';
$lang['oldpass']               = 'Confirmă parola curentă';
$lang['passchk']               = 'încă o dată';
$lang['remember']              = 'Ţine-mă minte';
$lang['fullname']              = 'Nume complet';
$lang['email']                 = 'E-Mail';
$lang['register']              = 'Înregistrează';
$lang['profile']               = 'Profil Utilizator';
$lang['badlogin']              = 'Imi pare rău, utilizatorul şi/sau parola au fost greşite.';
$lang['minoredit']             = 'Modificare Minoră';
$lang['draftdate']             = 'Schiţă salvată automat la';
$lang['regmissing']            = 'Ne pare rău, trebuie să completezi toate cîmpurile.';
$lang['reguexists']            = 'Ne pare rău, un utilizator cu acest nume există deja logat.';
$lang['regsuccess']            = 'Utilizatorul a fost creat. Parola a fost trimisă prin email.';
$lang['regsuccess2']           = 'Utilizatorul a fost creat.';
$lang['regmailfail']           = 'Se pare că a fost o eroare la trimiterea parolei prin email. Contactaţi administratorul!';
$lang['regbadmail']            = 'Adresa de email este invalidă - dacă credeţi că este o eroare contactaţi administratorul.';
$lang['regbadpass']            = 'Cele două parole furnizate nu sunt identice; încercaţi din nou.';
$lang['regpwmail']             = 'Parola ta DokuWiki';
$lang['reghere']               = 'Înca nu ai un cont? Fă-ţi unul';
$lang['profna']                = 'Această wiki nu suportă modificarea profilului';
$lang['profnochange']          = 'Nici o modificare; nimic de făcut.';
$lang['profnoempty']           = 'Nu sunt admise numele sau adresa de email necompletate.';
$lang['profchanged']           = 'Profilul de utilizator a fost actualizat succes.';
$lang['pwdforget']             = 'Parola uitată? Luaţi una nouă';
$lang['resendna']              = 'Această wiki nu suportă retrimiterea parolei.';
$lang['resendpwd']             = 'Trimite parola nouă pentru';
$lang['resendpwdmissing']      = 'Ne pare rău, trebuie completate toate câmpurile.';
$lang['resendpwdnouser']       = 'Ne pare rău, acest utilizator nu poate fi găsit în baza de date.';
$lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verificaţi dacă aţi folosit tot link-ul de confirmare.';
$lang['resendpwdconfirm']      = 'Un link de confirmare a fost trimis prin email.';
$lang['resendpwdsuccess']      = 'Parola nouă';
$lang['txt_upload']            = 'Selectează fisierul de încărcat';
$lang['txt_filename']          = 'Încarcă fişierul ca (opţional)';
$lang['txt_overwrt']           = 'Suprascrie fişierul existent';
$lang['lockedby']              = 'Momentan blocat de';
$lang['lockexpire']            = 'Blocarea expiră la';
$lang['willexpire']            = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele foloseşte butonul de previzualizare pentru resetarea blocării.';
$lang['notsavedyet']           = 'Există modificări nesalvate, care se vor pierde.\nDoreşti să continui?';
$lang['rssfailed']             = 'A apărut o eroare in timpul descărcării acestui cîmp: ';
$lang['nothingfound']          = 'Nu am găsit nimic.';
$lang['mediaselect']           = 'Selectare fişiere media';
$lang['fileupload']            = 'Încarcă fişier media';
$lang['uploadsucc']            = 'Încărcare reuşită';
$lang['uploadfail']            = 'Încărcare eşuată. Poate din cauza permisiunilor?';
$lang['uploadwrong']           = 'Încărcare nepermisă. Extensia fişierului e nepermisă';
$lang['uploadexist']           = 'Fişierul există deja. Nimic nu a fost făcut.';
$lang['uploadbadcontent']      = 'Conţinutul încărcat nu corespunde extensiei fişierului %s.';
$lang['uploadspam']            = 'Încărcarea a fost blocată datorită listei negre de spam.';
$lang['uploadxss']             = 'Încărcarea a fost blocată datorită unui posibil conţinut dăunător.';
$lang['deletesucc']            = 'Fişierul "%s" a fost şters.';
$lang['deletefail']            = '"%s" nu a putut fi şters - verificaţi drepturile.';
$lang['mediainuse']            = 'Fişierul "%s" nu a fost şters - este încă în uz.';
$lang['namespaces']            = 'Spaţii de nume';
$lang['mediafiles']            = 'Fişiere disponibile în';
$lang['js']['keepopen']        = 'Menţine fereastra deschisă la selecţie';
$lang['js']['hidedetails']     = 'Ascunde Detalii';
$lang['mediausage']            = 'Folosiţi următoarea sintaxă pentru a face referinţă la acest fişier:';
$lang['mediaview']             = 'Vizualizează fişierul original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Încarcă un fişier in acest spaţiu de nume. Pentru a crea sub-spaţii de nume, adaugă-le la fişierul de încărcat, separate de doua puncte (:).';
$lang['mediaextchange']        = 'Extensia fişierului a fost modificată din .%s în .%s!';
$lang['reference']             = 'Referinţă pentru';
$lang['ref_inuse']             = 'Fişierul nu a putut fi şters întrucât este folosit încă de următoarele pagini:';
$lang['ref_hidden']            = 'Nu aveţi permisiunea să citiţi o parte din referinţele din pagină.';
$lang['hits']                  = 'Hituri';
$lang['quickhits']             = 'Nume de pagini potrivite';
$lang['toc']                   = 'Cuprins';
$lang['current']               = 'curent';
$lang['yours']                 = 'Versiunea ta';
$lang['diff']                  = 'arată diferenţele faţă de versiunea curentă';
$lang['diff2']                 = 'Arată diferenţele dintre versiunile selectate';
$lang['line']                  = 'Linia';
$lang['breadcrumb']            = 'Traseu';
$lang['youarehere']            = 'Sunteţi aici';
$lang['lastmod']               = 'Ultima modificare';
$lang['by']                    = 'de către';
$lang['deleted']               = 'şters';
$lang['created']               = 'creat';
$lang['restored']              = 'versiune veche restaurată';
$lang['external_edit']         = 'editare externă';
$lang['summary']               = 'Editează sumarul';
$lang['mail_newpage']          = 'pagina adăugată:';
$lang['mail_changed']          = 'page schimbată:';
$lang['mail_new_user']         = 'utilizator nou';
$lang['mail_upload']           = 'fişier încărcat:';
$lang['nosmblinks']            = 'Legăturile către sharing-uri Windows funcţioneaza numai in Microsoft Internet Explorer.\nPuteţi însă copia şi insera legătura.';
$lang['qb_alert']              = 'Introduceţi vă rog textul care doriţi să-l formataţi.\nVa fi adăugat la sfîtşitul documentului.';
$lang['qb_bold']               = 'Text Îngroşat';
$lang['qb_italic']             = 'Text Italic';
$lang['qb_underl']             = 'Text Subliniat';
$lang['qb_code']               = 'Text Cod';
$lang['qb_strike']             = 'Text Tăiat';
$lang['qb_h1']                 = 'Titlu de Nivel 1';
$lang['qb_h2']                 = 'Titlu de Nivel 2';
$lang['qb_h3']                 = 'Titlu de Nivel 3';
$lang['qb_h4']                 = 'Titlu de Nivel 4';
$lang['qb_h5']                 = 'Titlu de Nivel 5';
$lang['qb_link']               = 'Legătură internă';
$lang['qb_extlink']            = 'Legătura externă';
$lang['qb_hr']                 = 'Linie Orizontal';
$lang['qb_ol']                 = 'Listă Ordonată';
$lang['qb_ul']                 = 'Listă Neordoată';
$lang['qb_media']              = 'Adaugă imagini şi alte fişiere';
$lang['qb_sig']                = 'Inserează semnătură';
$lang['qb_smileys']            = 'Smiley-uri';
$lang['qb_chars']              = 'Caractere speciale';
$lang['del_confirm']           = 'Doriţi într-adevăr ştergerea elementelor selectate?';
$lang['admin_register']        = 'Adaugă utilizator nou';
$lang['metaedit']              = 'Editează Metadata';
$lang['metasaveerr']           = 'Scrierea metadatelor a eşuat';
$lang['metasaveok']            = 'Metadatele au fost salvate';
$lang['img_backto']            = 'Înapoi la';
$lang['img_title']             = 'Titlu';
$lang['img_caption']           = 'Legendă';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Nume fişier';
$lang['img_fsize']             = 'Dimensiune';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Camera';
$lang['img_keywords']          = 'Cuvinte cheie';
$lang['subscribe_success']     = 'A fost adăugat %s la lista de subscriere pentru %s';
$lang['subscribe_error']       = 'Eroare la adăugarea %s la lista de subscriere pentru %s';
$lang['subscribe_noaddress']   = 'Nu este nici o adresă de mail asociată cu utilizatorul dvs. Nu puteţi fi adăugat la lista de subscriere';
$lang['unsubscribe_success']   = '%s a fost eliminat din lista de subscriere pentru %s';
$lang['unsubscribe_error']     = 'Eroare la eliminarea %s din lista de subscriere pentru %s';
$lang['authmodfailed']         = 'Configuraţia autentificării utilizatorului este eronată. Anunţaţi Wiki Admin-ul.';
$lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Anunţaţi Wiki Admin-ul.';
$lang['i_chooselang']          = 'Alegeţi limba';
$lang['i_installer']           = 'DokuWiki Installer';
$lang['i_wikiname']            = 'Numele Wiki';
$lang['i_enableacl']           = 'Activează ACL (recomandat)';
$lang['i_superuser']           = 'Superutilizator';
$lang['i_problems']            = 'Programul de instalare a găsit câteva probleme, indicate mai jos. Nu puteţi continua până nu le rezolvaţi.';
$lang['i_modified']            = 'Din motive de securitate, acest script va funcţiona doar cu o instalare nouă şi nemodificată a Docuwiki.
Puteţi fie să extrageţi din nou fişierele din arhiva descărcată fie să consultaţi instrucţiunile de instalare Dokuwiki la <a href="http://wiki.splitbrain.org/wiki:install">';
$lang['i_funcna']              = 'Funcţia PHP <code>%s</code> nu este disponibilă. Probabil provider-ul dvs. a inactivat-o pentru un motiv oarecare.';
$lang['i_phpver']              = 'Versiunea dvs. de PHP <code>%s</code> este mai veche decât cea necesară (<code>%s</code>). Trebuie să vă actualizaţi instalarea PHP.';
$lang['i_permfail']            = '<code>%s</code> nu poate fi scris de către DokuWiki. Trebuie să modificaţi drepturile acestui director!';
$lang['i_confexists']          = '<code>%s</code> există deja';
$lang['i_writeerr']            = 'Nu s-a putut crea <code>%s</code>. Trebuie să verificaţi drepturile directorului/fişierului şi să creaţi fişierul manual.';
$lang['i_badhash']             = 'dokuwiki.php nu a fost recunoscut sau a fost modificat (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valoare nepemisă sau neintrodusă';
$lang['i_success']             = 'Configurarea a fost finalizată cu succes. Acum puteţi sterge fişierul install.php. Continuaţi cu <a href="doku.php">your new DokuWiki</a>.';
$lang['i_failure']             = 'Au apărut erori la scrierea fişierelor de configurare. Va trebui să le corectaţi manual înainte de a putea folosi <a href="doku.php">your new DokuWiki</a>.';
$lang['i_policy']              = 'Politica ACL iniţială';
$lang['i_pol0']                = 'Wiki Deschisă (citeşte, scrie şi încarcă oricine)';
$lang['i_pol1']                = 'Wiki Deschisă (citeste oricine, scrie şi încarcă doar utilizatorul înregistrat)';
$lang['i_pol2']                = 'Wiki Închisă (citeşte, scrie şi încarcă doar utilizatorul înregistrat)';
$lang['i_retry']               = 'Încearcă din nou';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/ro/lang.php <==
<?php
/**
 * romanian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Tiberiu Micu <tibimicu@gmx.net>
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 * @author Emanuel-Emeric Andrasi <n30@mandrivausers.ro>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Editează această pagină';
$lang['btn_source']            = 'Arată sursa paginii';
$lang['btn_show']              = 'Arată pagina';
$lang['btn_create']            = 'Crează această pagină';
$lang['btn_search']            = 'Caută';
$lang['btn_save']              = 'Salvează';
$lang['btn_preview']           = 'Previzualizează';
$lang['btn_top']               = 'La început';
$lang['btn_newer']             = '<< mai recent';
$lang['btn_older']             = 'mai vechi>>';
$lang['btn_revs']              = 'Versiuni vechi';
$lang['btn_recent']            = 'Modificări recente';
$lang['btn_upload']            = 'Upload';
$lang['btn_cancel']            = 'Renunţare';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Editează';
$lang['btn_login']             = 'Login';
$lang['btn_logout']            = 'Logout';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Actualizează';
$lang['btn_delete']            = 'Şterge';
$lang['btn_back']              = 'Înapoi';
$lang['btn_backlink']          = 'Legătură anterioară';
$lang['btn_backtomedia']       = 'Înapoi la Selecţia Mediafile';
$lang['btn_subscribe']         = 'Subscrie Modificarea Paginii';
$lang['btn_unsubscribe']       = 'Anulează Subscrierea Modificării Paginii';
$lang['btn_subscribens']       = 'Subscrie Modificarea Spaţiului de Nume';
$lang['btn_unsubscribens']     = 'Anulează Subscrierea Modificării Spaţiului de Nume';
$lang['btn_profile']           = 'Actualizează Profil';
$lang['btn_reset']             = 'Resetează';
$lang['btn_resendpwd']         = 'Trimite parola nouă';
$lang['btn_draft']             = 'Editează schiţă';
$lang['btn_recover']           = 'Recuperează schiţă';
$lang['btn_draftdel']          = 'Şterge schiţă';
$lang['loggedinas']            = 'Logat ca şi';
$lang['user']                  = 'Utilizator';
$lang['pass']                  = 'Parola';
$lang['newpass']               = 'Parola nouă';
$lang['oldpass']               = 'Confirmă parola curentă';
$lang['passchk']               = 'încă o dată';
$lang['remember']              = 'Ţine-mă minte';
$lang['fullname']              = 'Nume complet';
$lang['email']                 = 'E-Mail';
$lang['register']              = 'Înregistrează';
$lang['profile']               = 'Profil Utilizator';
$lang['badlogin']              = 'Imi pare rău, utilizatorul şi/sau parola au fost greşite.';
$lang['minoredit']             = 'Modificare Minoră';
$lang['draftdate']             = 'Schiţă salvată automat la';
$lang['nosecedit']             = 'Pagina s-a modificat între timp, secţiunea info a expirat, s-a încărcat pagina întreagă în loc.';
$lang['regmissing']            = 'Ne pare rău, trebuie să completezi toate cîmpurile.';
$lang['reguexists']            = 'Ne pare rău, un utilizator cu acest nume există deja logat.';
$lang['regsuccess']            = 'Utilizatorul a fost creat. Parola a fost trimisă prin email.';
$lang['regsuccess2']           = 'Utilizatorul a fost creat.';
$lang['regmailfail']           = 'Se pare că a fost o eroare la trimiterea parolei prin email. Contactaţi administratorul!';
$lang['regbadmail']            = 'Adresa de email este invalidă - dacă credeţi că este o eroare contactaţi administratorul.';
$lang['regbadpass']            = 'Cele două parole furnizate nu sunt identice; încercaţi din nou.';
$lang['regpwmail']             = 'Parola ta DokuWiki';
$lang['reghere']               = 'Înca nu ai un cont? Fă-ţi unul';
$lang['profna']                = 'Această wiki nu suportă modificarea profilului';
$lang['profnochange']          = 'Nici o modificare; nimic de făcut.';
$lang['profnoempty']           = 'Nu sunt admise numele sau adresa de email necompletate.';
$lang['profchanged']           = 'Profilul de utilizator a fost actualizat succes.';
$lang['pwdforget']             = 'Parola uitată? Luaţi una nouă';
$lang['resendna']              = 'Această wiki nu suportă retrimiterea parolei.';
$lang['resendpwd']             = 'Trimite parola nouă pentru';
$lang['resendpwdmissing']      = 'Ne pare rău, trebuie completate toate câmpurile.';
$lang['resendpwdnouser']       = 'Ne pare rău, acest utilizator nu poate fi găsit în baza de date.';
$lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verificaţi dacă aţi folosit tot link-ul de confirmare.';
$lang['resendpwdconfirm']      = 'Un link de confirmare a fost trimis prin email.';
$lang['resendpwdsuccess']      = 'Parola nouă';
$lang['license']               = 'Exceptând locurile unde este altfel specificat, conţinutul acestui wiki este licenţiat sub următoarea licenţă:';
$lang['licenseok']             = 'Notă: Prin editarea acestei pagini sunteţi de acord să vă licenţiaţi conţintul sub următoarea licenţă:';
$lang['txt_upload']            = 'Selectează fisierul de încărcat';
$lang['txt_filename']          = 'Încarcă fişierul ca (opţional)';
$lang['txt_overwrt']           = 'Suprascrie fişierul existent';
$lang['lockedby']              = 'Momentan blocat de';
$lang['lockexpire']            = 'Blocarea expiră la';
$lang['willexpire']            = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele foloseşte butonul de previzualizare pentru resetarea blocării.';
$lang['notsavedyet']           = 'Există modificări nesalvate, care se vor pierde.\nDoreşti să continui?';
$lang['rssfailed']             = 'A apărut o eroare in timpul descărcării acestui cîmp: ';
$lang['nothingfound']          = 'Nu am găsit nimic.';
$lang['mediaselect']           = 'Selectare fişiere media';
$lang['fileupload']            = 'Încarcă fişier media';
$lang['uploadsucc']            = 'Încărcare reuşită';
$lang['uploadfail']            = 'Încărcare eşuată. Poate din cauza permisiunilor?';
$lang['uploadwrong']           = 'Încărcare nepermisă. Extensia fişierului e nepermisă';
$lang['uploadexist']           = 'Fişierul există deja. Nimic nu a fost făcut.';
$lang['uploadbadcontent']      = 'Conţinutul încărcat nu corespunde extensiei fişierului %s.';
$lang['uploadspam']            = 'Încărcarea a fost blocată datorită listei negre de spam.';
$lang['uploadxss']             = 'Încărcarea a fost blocată datorită unui posibil conţinut dăunător.';
$lang['uploadsize']            = 'Fişierul uploadat a fost prea mare. (max %s)';
$lang['deletesucc']            = 'Fişierul "%s" a fost şters.';
$lang['deletefail']            = '"%s" nu a putut fi şters - verificaţi drepturile.';
$lang['mediainuse']            = 'Fişierul "%s" nu a fost şters - este încă în uz.';
$lang['namespaces']            = 'Spaţii de nume';
$lang['mediafiles']            = 'Fişiere disponibile în';
$lang['js']['keepopen']        = 'Menţine fereastra deschisă la selecţie';
$lang['js']['hidedetails']     = 'Ascunde Detalii';
$lang['js']['nosmblinks']      = 'Legăturile către sharing-uri Windows funcţioneaza numai in Microsoft Internet Explorer.
Puteţi însă copia şi insera legătura.';
$lang['js']['mu_btn']          = 'Încarcă mai multe fişiere simultan';
$lang['mediausage']            = 'Folosiţi următoarea sintaxă pentru a face referinţă la acest fişier:';
$lang['mediaview']             = 'Vizualizează fişierul original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Încarcă un fişier in acest spaţiu de nume. Pentru a crea sub-spaţii de nume, adaugă-le la fişierul de încărcat, separate de doua puncte (:).';
$lang['mediaextchange']        = 'Extensia fişierului a fost modificată din .%s în .%s!';
$lang['reference']             = 'Referinţă pentru';
$lang['ref_inuse']             = 'Fişierul nu a putut fi şters întrucât este folosit încă de următoarele pagini:';
$lang['ref_hidden']            = 'Nu aveţi permisiunea să citiţi o parte din referinţele din pagină.';
$lang['hits']                  = 'Hituri';
$lang['quickhits']             = 'Nume de pagini potrivite';
$lang['toc']                   = 'Cuprins';
$lang['current']               = 'curent';
$lang['yours']                 = 'Versiunea ta';
$lang['diff']                  = 'arată diferenţele faţă de versiunea curentă';
$lang['diff2']                 = 'Arată diferenţele dintre versiunile selectate';
$lang['line']                  = 'Linia';
$lang['breadcrumb']            = 'Traseu';
$lang['youarehere']            = 'Sunteţi aici';
$lang['lastmod']               = 'Ultima modificare';
$lang['by']                    = 'de către';
$lang['deleted']               = 'şters';
$lang['created']               = 'creat';
$lang['restored']              = 'versiune veche restaurată';
$lang['external_edit']         = 'editare externă';
$lang['summary']               = 'Editează sumarul';
$lang['noflash']               = 'Plugin-ul <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> este necesar pentru afişarea corectă a conţinutului.';
$lang['mail_newpage']          = 'pagina adăugată:';
$lang['mail_changed']          = 'page schimbată:';
$lang['mail_new_user']         = 'utilizator nou';
$lang['mail_upload']           = 'fişier încărcat:';
$lang['qb_alert']              = 'Introduceţi vă rog textul care doriţi să-l formataţi.\nVa fi adăugat la sfîtşitul documentului.';
$lang['qb_bold']               = 'Text Îngroşat';
$lang['qb_italic']             = 'Text Italic';
$lang['qb_underl']             = 'Text Subliniat';
$lang['qb_code']               = 'Text Cod';
$lang['qb_strike']             = 'Text Tăiat';
$lang['qb_h1']                 = 'Titlu de Nivel 1';
$lang['qb_h2']                 = 'Titlu de Nivel 2';
$lang['qb_h3']                 = 'Titlu de Nivel 3';
$lang['qb_h4']                 = 'Titlu de Nivel 4';
$lang['qb_h5']                 = 'Titlu de Nivel 5';
$lang['qb_link']               = 'Legătură internă';
$lang['qb_extlink']            = 'Legătura externă';
$lang['qb_hr']                 = 'Linie Orizontal';
$lang['qb_ol']                 = 'Listă Ordonată';
$lang['qb_ul']                 = 'Listă Neordoată';
$lang['qb_media']              = 'Adaugă imagini şi alte fişiere';
$lang['qb_sig']                = 'Inserează semnătură';
$lang['qb_smileys']            = 'Smiley-uri';
$lang['qb_chars']              = 'Caractere speciale';
$lang['del_confirm']           = 'Doriţi într-adevăr ştergerea elementelor selectate?';
$lang['admin_register']        = 'Adaugă utilizator nou';
$lang['metaedit']              = 'Editează Metadata';
$lang['metasaveerr']           = 'Scrierea metadatelor a eşuat';
$lang['metasaveok']            = 'Metadatele au fost salvate';
$lang['img_backto']            = 'Înapoi la';
$lang['img_title']             = 'Titlu';
$lang['img_caption']           = 'Legendă';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Nume fişier';
$lang['img_fsize']             = 'Dimensiune';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Camera';
$lang['img_keywords']          = 'Cuvinte cheie';
$lang['subscribe_success']     = 'A fost adăugat %s la lista de subscriere pentru %s';
$lang['subscribe_error']       = 'Eroare la adăugarea %s la lista de subscriere pentru %s';
$lang['subscribe_noaddress']   = 'Nu este nici o adresă de mail asociată cu utilizatorul dvs. Nu puteţi fi adăugat la lista de subscriere';
$lang['unsubscribe_success']   = '%s a fost eliminat din lista de subscriere pentru %s';
$lang['unsubscribe_error']     = 'Eroare la eliminarea %s din lista de subscriere pentru %s';
$lang['authmodfailed']         = 'Configuraţia autentificării utilizatorului este eronată. Anunţaţi Wiki Admin-ul.';
$lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Anunţaţi Wiki Admin-ul.';
$lang['i_chooselang']          = 'Alegeţi limba';
$lang['i_installer']           = 'DokuWiki Installer';
$lang['i_wikiname']            = 'Numele Wiki';
$lang['i_enableacl']           = 'Activează ACL (recomandat)';
$lang['i_superuser']           = 'Superutilizator';
$lang['i_problems']            = 'Programul de instalare a găsit câteva probleme, indicate mai jos. Nu puteţi continua până nu le rezolvaţi.';
$lang['i_modified']            = 'Din motive de securitate, acest script va funcţiona doar cu o instalare nouă şi nemodificată a Docuwiki.
Puteţi fie să extrageţi din nou fişierele din arhiva descărcată fie să consultaţi instrucţiunile de instalare Dokuwiki la <a href="http://dokuwiki.org/install">';
$lang['i_funcna']              = 'Funcţia PHP <code>%s</code> nu este disponibilă. Probabil provider-ul dvs. a inactivat-o pentru un motiv oarecare.';
$lang['i_phpver']              = 'Versiunea dvs. de PHP <code>%s</code> este mai veche decât cea necesară (<code>%s</code>). Trebuie să vă actualizaţi instalarea PHP.';
$lang['i_permfail']            = '<code>%s</code> nu poate fi scris de către DokuWiki. Trebuie să modificaţi drepturile acestui director!';
$lang['i_confexists']          = '<code>%s</code> există deja';
$lang['i_writeerr']            = 'Nu s-a putut crea <code>%s</code>. Trebuie să verificaţi drepturile directorului/fişierului şi să creaţi fişierul manual.';
$lang['i_badhash']             = 'dokuwiki.php nu a fost recunoscut sau a fost modificat (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valoare nepemisă sau neintrodusă';
$lang['i_success']             = 'Configurarea a fost finalizată cu succes. Acum puteţi sterge fişierul install.php. Continuaţi cu <a href="doku.php">your new DokuWiki</a>.';
$lang['i_failure']             = 'Au apărut erori la scrierea fişierelor de configurare. Va trebui să le corectaţi manual înainte de a putea folosi <a href="doku.php">your new DokuWiki</a>.';
$lang['i_policy']              = 'Politica ACL iniţială';
$lang['i_pol0']                = 'Wiki Deschisă (citeşte, scrie şi încarcă oricine)';
$lang['i_pol1']                = 'Wiki Deschisă (citeste oricine, scrie şi încarcă doar utilizatorul înregistrat)';
$lang['i_pol2']                = 'Wiki Închisă (citeşte, scrie şi încarcă doar utilizatorul înregistrat)';
$lang['i_retry']               = 'Încearcă din nou';
$lang['mu_intro']              = 'Aici poţi încărca mai multe fişiere simultan. Apasă butonul Răsfoieşte pentru a le adăuga. Apasă Încarcă când ai terminat.';
$lang['mu_gridname']           = 'Numele fişierului';
$lang['mu_gridsize']           = 'Mărime';
$lang['mu_gridstat']           = 'Stare';
$lang['mu_namespace']          = 'Spaţiu de nume';
$lang['mu_browse']             = 'Răsfoieşte';
$lang['mu_toobig']             = 'prea mare';
$lang['mu_ready']              = 'pregătit pentru încărcare';
$lang['mu_done']               = 'complet';
$lang['mu_fail']               = 'eşuat';
$lang['mu_authfail']           = 'sesiunea a expirat';
$lang['mu_progress']           = '@PCT@% incărcat';
$lang['mu_filetypes']          = 'Tipuri de fişiere permise';
$lang['recent_global']         = 'Acum vizualizaţi modificările în interiorul numelui de spaţiu <b>%s</b>. De asemenea puteţi <a href="%s">vizualiza modificările recente ale întregului wiki</a>.';
